@@ -1,11 +1,11 @@
 /*******************************************************************************
  * @license
- * Copyright (c) 2013 IBM Corporation and others. 
- * All rights reserved. This program and the accompanying materials are made 
- * available under the terms of the Eclipse Public License v1.0 
- * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
- * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
- * 
+ * Copyright (c) 2013, 2016 IBM Corporation and others.
+ * All rights reserved. This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License v1.0
+ * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution
+ * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html).
+ *
  * Contributors: IBM Corporation - initial API and implementation
  ******************************************************************************/
 /*global URL*/
@@ -38,13 +38,13 @@ define([
 	var NavigatorRenderer = mNavigatorRenderer.NavigatorRenderer;
 
 	var uriTemplate = new URITemplate("#{,resource,params*}"); //$NON-NLS-0$
-	
+
 	/**
 	 * @class orion.sidebar.CommonNavExplorer
 	 * @extends orion.explorers.FileExplorer
 	 */
 	function CommonNavExplorer(params) {
-		params.setFocus = false;   // do not steal focus on load
+		params.setFocus = false; // do not steal focus on load
 		params.cachePrefix = null; // do not persist table state
 		params.modelEventDispatcher = FileCommands.getModelEventDispatcher();
 		params.dragAndDrop = FileCommands.uploadFile;
@@ -64,86 +64,75 @@ define([
 		this.viewActionsScope = "viewActions"; //$NON-NLS-0$
 		this.toolsActionsScope = "toolsActions"; //$NON-NLS-0$
 		this.additionalActionsScope = "extraActions"; //$NON-NLS-0$
-		
+
 		this._parentNode = lib.node(this.parentId);
-		this._sidebarContextMenuNode = document.createElement("ul"); //$NON-NLS-0$
+		this._sidebarContextMenuNode = document.createElement("ul");
 		this._sidebarContextMenuNode.className = "dropdownMenu"; //$NON-NLS-0$
 		this._sidebarContextMenuNode.setAttribute("role", "menu"); //$NON-NLS-1$ //$NON-NLS-0$
 		this._sidebarContextMenuNode.id = this.parentId + "ContextMenu"; //$NON-NLS-0$
-		
+
 		this._parentNode.parentNode.insertBefore(this._sidebarContextMenuNode, this._parentNode);
-		
+
 		this.contextMenuActionsScope = this._sidebarContextMenuNode.id + "commonNavContextMenu"; //$NON-NLS-0$
 
 		this.treeRoot = {}; // Needed by FileExplorer.prototype.loadResourceList
 		var _self = this;
- 		this.editorInputListener = function(event) {
-			_self.reveal(event.metadata).then(function() {
+		this.editorInputListener = function(evnt) {
+			_self.reveal(evnt.metadata).then(function() {
 				mMetrics.logPageLoadTiming("complete", window.location.pathname); //$NON-NLS-0$
 			});
- 		};
-		this.editorInputManager.addEventListener("InputChanged", this.editorInputListener); //$NON-NLS-0$
+		};
+		this.editorInputManager.addEventListener("InputChanged", this.editorInputListener);
 		if (sidebarNavInputManager) {
 			sidebarNavInputManager.reveal = function(metadata) {
 				_self.reveal(metadata);
 			};
-			
+
 			// Broadcast changes of our explorer root to the sidebarNavInputManager
-			this.addEventListener("rootChanged", function(event) { //$NON-NLS-0$
-				sidebarNavInputManager.dispatchEvent(event);
+			this.addEventListener("rootChanged", function(evnt) {
+				sidebarNavInputManager.dispatchEvent(evnt);
 			});
 		}
 		this.selection = new Selection.Selection(this.registry, "commonNavFileSelection"); //$NON-NLS-0$
-		this._selectionListener = function(event) { //$NON-NLS-0$
-			_self.updateCommands(event.selections);
+		this._selectionListener = function(evnt) {
+			_self.updateCommands(evnt.selections);
 			if (sidebarNavInputManager) {
-				_self.sidebarNavInputManager.dispatchEvent(event);
+				_self.sidebarNavInputManager.dispatchEvent(evnt);
 			}
 		};
-		this.selection.addEventListener("selectionChanged", this._selectionListener); //$NON-NLS-0$
-		mGlobalCommands.getMainSplitter().splitter.addEventListener("toggle", this._splitterToggleListener = function(e) { //$NON-NLS-0$
+		this.selection.addEventListener("selectionChanged", this._selectionListener);
+		mGlobalCommands.getMainSplitter().splitter.addEventListener("toggle", this._splitterToggleListener = /* @callback */ function(e) {
 			this.updateCommands();
 		}.bind(this));
 		this.commandsRegistered = this.registerCommands();
-		
+
 		this._createContextMenu();
 	}
 	CommonNavExplorer.prototype = Object.create(FileExplorer.prototype);
 	objects.mixin(CommonNavExplorer.prototype, /** @lends orion.sidebar.CommonNavExplorer.prototype */ {
-//		onLinkClick: function(event) {
-//			FileExplorer.prototype.onLinkClick.call(this, event);
-//			//Redispatch to nav input manager
-//			this.sidebarNavInputManager.dispatchEvent(event);
-//			var navHandler = this.getNavHandler();
-//			if (!navHandler || !event.item.Directory) {
-//				return;
-//			}
-//			var folder = event.item;
-//			navHandler.cursorOn(folder);
-//			navHandler.setSelection(folder, false);
-//		},
 		isDesktopSelectionMode: function() {
-			return	this.generalPreferences.getPrefs().then(function (genealPrefs) {
+			return this.generalPreferences.getPrefs().then(function(genealPrefs) {
 				return genealPrefs.desktopSelectionPolicy;
-			}.bind(this));
+			});
 		},
 		onModelCreate: function(evt) {
-			return FileExplorer.prototype.onModelCreate.call(this, evt).then(function () {
-				if(evt && evt.select) {
+			return FileExplorer.prototype.onModelCreate.call(this, evt).then(function() {
+				if (evt && evt.select) {
 					this.sidebarNavInputManager.dispatchEvent(evt);
 				}
 			}.bind(this));
 		},
 		// Override the same API from the super class to dispatch "editorInputMoved" event
 		handleResourceChange: function(evt) {
-			return FileExplorer.prototype.handleResourceChange.call(this, evt).then(function (newEvt) {
-				if((evt.deleted || evt.moved) && newEvt) {
+			return FileExplorer.prototype.handleResourceChange.call(this, evt).then(function(newEvt) {
+				if ((evt.deleted || evt.moved) && newEvt) {
 					this.onFileModelChange(newEvt);
 				}
 			}.bind(this));
 		},
-		onFileModelChange: function(event) {
-			var oldValue = event.oldValue, newValue = event.newValue;
+		onFileModelChange: function(evnt) {
+			var oldValue = evnt.oldValue,
+				newValue = evnt.newValue;
 			// Detect if we moved/renamed/deleted the current file being edited, or an ancestor thereof.
 			var editorFile = this.editorInputManager.getFileMetadata();
 			if (!editorFile) {
@@ -163,7 +152,9 @@ define([
 					// Current file was the target, see if we know its new name
 					newInput = (newValue && newValue.ChildrenLocation) || (newValue && newValue.ContentLocation) || (newValue && newValue.Location) || null;
 					if (newInput) {
-						newInput = {resource: newInput};
+						newInput = {
+							resource: newInput
+						};
 						if (newInput.resource === newValue.Location) {
 							var url = this.editorInputManager.selection.getSelection();
 							var match = /^[^,]+,(.*)$/.exec(url);
@@ -188,7 +179,7 @@ define([
 			// CommandRegistry seems to require dropdowns to have their own element.
 			[].forEach(function(id) {
 				if (!_self[id]) {
-					var elem = document.createElement("ul"); //$NON-NLS-0$
+					var elem = document.createElement("ul");
 					elem.id = id;
 					elem.classList.add("commandList"); //$NON-NLS-0$
 					elem.classList.add("layoutLeft"); //$NON-NLS-0$
@@ -198,18 +189,18 @@ define([
 				}
 			});
 		},
-		
+
 		destroy: function() {
 			var _self = this;
 			FileExplorer.prototype.destroy.call(this);
 			[].forEach(function(id) {
 				delete _self[id];
 			});
-			this.editorInputManager.removeEventListener("InputChanged", this.editorInputListener); //$NON-NLS-0$
-			this.selection.removeEventListener("selectionChanged", this._selectionListener); //$NON-NLS-0$
+			this.editorInputManager.removeEventListener("InputChanged", this.editorInputListener);
+			this.selection.removeEventListener("selectionChanged", this._selectionListener);
 			var mainSplitter = mGlobalCommands.getMainSplitter();
-			if(mainSplitter) {
-				mainSplitter.splitter.removeEventListener("toggle", this._splitterToggleListener); //$NON-NLS-0$
+			if (mainSplitter) {
+				mainSplitter.splitter.removeEventListener("toggle", this._splitterToggleListener);
 			}
 			if (this._contextMenu) {
 				this._contextMenu.destroy();
@@ -221,12 +212,12 @@ define([
 			}
 		},
 		display: function(root, force) {
-			return this.loadRoot(root, force).then(function(){
+			return this.loadRoot(root, force).then(function() {
 				this.updateCommands();
 				return this.reveal(this.editorInputManager.getFileMetadata()).then(function() {
 					mMetrics.logPageLoadTiming("complete", window.location.pathname); //$NON-NLS-0$
 				});
-			}.bind(this));	
+			}.bind(this));
 		},
 		/**
 		 * Loads the given children location as the root.
@@ -234,17 +225,16 @@ define([
 		 * @returns {orion.Promise}
 		 */
 		loadRoot: function(childrenLocation, force) {
-			childrenLocation = (childrenLocation && childrenLocation.ChildrenLocation) || childrenLocation || ""; //$NON-NLS-0$
+			childrenLocation = (childrenLocation && childrenLocation.ChildrenLocation) || childrenLocation || "";
 			return this.commandsRegistered.then(function() {
-				if (childrenLocation && typeof childrenLocation === "object") { //$NON-NLS-0$
+				if (childrenLocation && typeof childrenLocation === "object") {
 					return this.load(childrenLocation);
-				} else {
-					return this.loadResourceList(childrenLocation, force);
 				}
+				return this.loadResourceList(childrenLocation, force);
 			}.bind(this));
 		},
 		scope: function(childrenLocation) {
-			childrenLocation = (childrenLocation && childrenLocation.ChildrenLocation) || childrenLocation || ""; //$NON-NLS-0$
+			childrenLocation = (childrenLocation && childrenLocation.ChildrenLocation) || childrenLocation || "";
 			var params = PageUtil.matchResourceParameters();
 			var resource = params.resource;
 			delete params.resource;
@@ -256,14 +246,17 @@ define([
 			} else {
 				delete params.navigate;
 			}
-			window.location.href = uriTemplate.expand({resource: resource, params: params});
+			window.location.href = uriTemplate.expand({
+				resource: resource,
+				params: params
+			});
 		},
 		scopeUp: function() {
 			var navigate;
 			var root = this.treeRoot;
-			var parent = root.Parents && root.Parents[0];
-			if (parent) {
-				navigate = parent.ChildrenLocation;
+			var prnt = root.Parents && root.Parents[0];
+			if (prnt) {
+				navigate = prnt.ChildrenLocation;
 			} else {
 				navigate = this.fileClient.fileServiceRootURL(root.Location);
 			}
@@ -286,7 +279,7 @@ define([
 			var editActionsScope = this.editActionsScope;
 			var viewActionsScope = this.viewActionsScope;
 			var contextMenuActionsScope = this.contextMenuActionsScope;
-		
+
 			var renameBinding = new KeyBinding(113, true); // F2
 			var delBinding = new KeyBinding(46); // Delete
 			var cutBinding = new KeyBinding('x', true); /* Ctrl+X */ //$NON-NLS-0$
@@ -294,12 +287,12 @@ define([
 			var pasteSelections = new KeyBinding('v', true); /* Ctrl+V */ //$NON-NLS-0$
 			var upFolder = new KeyBinding(38, false, false, true); /* Alt+UpArrow */
 			var downFolder = new KeyBinding(40, false, false, true); /* Alt+DownArrow */
-			downFolder.domScope = upFolder.domScope = pasteSelections.domScope = copySelections.domScope = cutBinding.domScope  = delBinding.domScope = typeof this.parentId === "string" ? this.parentId : this.parentId.id; //$NON-NLS-0$
-			downFolder.scopeName = upFolder.scopeName = pasteSelections.scopeName = copySelections.scopeName = cutBinding.scopeName  = delBinding.scopeName  = messages.Navigator; //$NON-NLS-0$
+			downFolder.domScope = upFolder.domScope = pasteSelections.domScope = copySelections.domScope = cutBinding.domScope = delBinding.domScope = typeof this.parentId === "string" ? this.parentId : this.parentId.id;
+			downFolder.scopeName = upFolder.scopeName = pasteSelections.scopeName = copySelections.scopeName = cutBinding.scopeName = delBinding.scopeName = messages.Navigator;
 
 			// New actions
 			commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.newFile", 1, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default"); //$NON-NLS-1$ //$NON-NLS-0$
-			commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.newFolder", 2, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default", false, null/*, new mCommandRegistry.URLBinding("newFolder", "name")*/); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+			commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.newFolder", 2, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default", false, null /*, new mCommandRegistry.URLBinding("newFolder", "name")*/ ); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(fileActionsScope, "orion.new.project", 3, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			if (!util.isElectron) {
 				commandRegistry.registerCommandContribution(fileActionsScope, "orion.new.linkProject", 4, "orion.menuBarFileGroup/orion.newContentGroup/orion.new.default"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
@@ -309,22 +302,20 @@ define([
 				// Import actions
 				commandRegistry.registerCommandContribution(fileActionsScope, "orion.import", 1, "orion.menuBarFileGroup/orion.importGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(fileActionsScope, "orion.importZipURL", 2, "orion.menuBarFileGroup/orion.importGroup"); //$NON-NLS-1$ //$NON-NLS-0$
-				commandRegistry.registerCommandContribution(fileActionsScope, "orion.importSFTP", 3, "orion.menuBarFileGroup/orion.importGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 
 				// Export actions
 				commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.downloadSingleFile", 1, "orion.menuBarFileGroup/orion.exportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.downloadFile", 2, "orion.menuBarFileGroup/orion.exportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
-				commandRegistry.registerCommandContribution(fileActionsScope, "eclipse.exportSFTPCommand", 3, "orion.menuBarFileGroup/orion.exportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 			}
-		
+
 			// Edit actions
 			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.cut", 1, "orion.menuBarEditGroup/orion.clipboardGroup", false, cutBinding); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.copySelections", 2, "orion.menuBarEditGroup/orion.clipboardGroup", false, copySelections); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.pasteSelections", 3, "orion.menuBarEditGroup/orion.clipboardGroup", false, pasteSelections); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.deleteFile", 4, "orion.menuBarEditGroup/orion.clipboardGroup", false, delBinding); //$NON-NLS-1$ //$NON-NLS-0$
-			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.compareWith", 5, "orion.menuBarEditGroup/orion.compareGroup");  //$NON-NLS-1$ //$NON-NLS-0$
-			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.compareWithEachOther", 6, "orion.menuBarEditGroup/orion.compareGroup");  //$NON-NLS-1$ //$NON-NLS-0$
-			
+			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.compareWith", 5, "orion.menuBarEditGroup/orion.compareGroup"); //$NON-NLS-1$ //$NON-NLS-0$
+			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.compareWithEachOther", 6, "orion.menuBarEditGroup/orion.compareGroup"); //$NON-NLS-1$ //$NON-NLS-0$
+
 			commandRegistry.registerCommandContribution(editActionsScope, "eclipse.renameResource", 1, "orion.menuBarEditGroup/orion.edit.formatGroup", false, renameBinding); //$NON-NLS-1$ //$NON-NLS-0$
 			// View actions
 			if (!util.isElectron) {
@@ -334,69 +325,67 @@ define([
 
 			commandRegistry.addCommandGroup(viewActionsScope, "eclipse.openWith", 1000, messages["OpenWith"], "orion.menuBarViewGroup", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.addCommandGroup(viewActionsScope, "eclipse.fileCommandExtensions", 1000, messages["OpenRelated"], "orion.menuBarViewGroup"); //$NON-NLS-1$ //$NON-NLS-0$
-			
+
 			// Context Menu
 			commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.commonNavContextMenuGroup", 100, null, null, null, null, null, "dropdownSelection"); //$NON-NLS-1$ //$NON-NLS-0$
-			
+
 			// Context Menu new artifact actions
 			commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.New", 0, messages["New"], "orion.commonNavContextMenuGroup/orion.newGroup", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.newFile", 1, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-1$ //$NON-NLS-0$
-			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.newFolder", 2, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New", false, null/*, new mCommandRegistry.URLBinding("newFolder", "name")*/); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.newFolder", 2, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New", false, null /*, new mCommandRegistry.URLBinding("newFolder", "name")*/ ); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.new.project", 3, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			if (!util.isElectron) {
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.new.linkProject", 4, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			}
-			
+
 			// Context Menu edit group actions
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.cut", 1, "orion.commonNavContextMenuGroup/orion.editGroup", false); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.copySelections", 2, "orion.commonNavContextMenuGroup/orion.editGroup", false); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.pasteSelections", 3, "orion.commonNavContextMenuGroup/orion.editGroup", false); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.deleteFile", 4, "orion.commonNavContextMenuGroup/orion.editGroup", false); //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.renameResource", 5, "orion.commonNavContextMenuGroup/orion.editGroup", false); //$NON-NLS-1$ //$NON-NLS-0$
-			
+
 			// Context Menu related actions
 			commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.OpenWith", 1001, messages["OpenWith"], "orion.commonNavContextMenuGroup/orion.relatedActions", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 			commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.Extensions", 1002, messages["OpenRelated"], "orion.commonNavContextMenuGroup/orion.relatedActions", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.compareWith", 6, "orion.commonNavContextMenuGroup/orion.relatedActions");  //$NON-NLS-1$ //$NON-NLS-0$
-			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.compareWithEachOther", 7, "orion.commonNavContextMenuGroup/orion.relatedActions");  //$NON-NLS-1$ //$NON-NLS-0$
-			
+			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.compareWith", 6, "orion.commonNavContextMenuGroup/orion.relatedActions"); //$NON-NLS-1$ //$NON-NLS-0$
+			commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.compareWithEachOther", 7, "orion.commonNavContextMenuGroup/orion.relatedActions"); //$NON-NLS-1$ //$NON-NLS-0$
+
 			if (!util.isElectron) {
 				// Context Menu import/export actions
-				commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.ImportGroup", 1003, messages["Import"], "orion.commonNavContextMenuGroup/orion.ImportExport", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$			
-				commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.ExportGroup", 1004, messages["Export"], "orion.commonNavContextMenuGroup/orion.ImportExport", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$						
+				commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.ImportGroup", 1003, messages["Import"], "orion.commonNavContextMenuGroup/orion.ImportExport", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+				commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.ExportGroup", 1004, messages["Export"], "orion.commonNavContextMenuGroup/orion.ImportExport", null, null, null, "dropdownSelection"); //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.import", 1, "orion.commonNavContextMenuGroup/orion.ImportExport/orion.ImportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.importZipURL", 2, "orion.commonNavContextMenuGroup/orion.ImportExport/orion.ImportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
-				commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.importSFTP", 3, "orion.commonNavContextMenuGroup/orion.ImportExport/orion.ImportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.downloadSingleFile", 1, "orion.commonNavContextMenuGroup/orion.ImportExport/orion.ExportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.downloadFile", 2, "orion.commonNavContextMenuGroup/orion.ImportExport/orion.ExportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
-				commandRegistry.registerCommandContribution(contextMenuActionsScope, "eclipse.exportSFTPCommand", 3, "orion.commonNavContextMenuGroup/orion.ImportExport/orion.ExportGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 			}
-			
+
 			// Context Menu search action
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.searchInFolder", 1, "orion.commonNavContextMenuGroup"); //$NON-NLS-0$
 			commandRegistry.registerCommandContribution(contextMenuActionsScope, "orion.problemsInFolder", 2, "orion.commonNavContextMenuGroup"); //$NON-NLS-0$
-			
-			
+
+
 			// Retrieve and register extension commands
-			ExtensionCommands.getOpenWithCommands(commandRegistry).forEach(function(command){
+			ExtensionCommands.getOpenWithCommands(commandRegistry).forEach(function(command) {
 				commandRegistry.registerCommandContribution(viewActionsScope, command.id, 1, "orion.menuBarViewGroup/eclipse.openWith"); //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, command.id, 1, "orion.commonNavContextMenuGroup/orion.relatedActions/orion.OpenWith"); //$NON-NLS-0$
 			});
-			
+
 			//TODO getFileCommands should return commands
-			ExtensionCommands.getFileCommandIds().forEach(function(commandId){
+			ExtensionCommands.getFileCommandIds().forEach(function(commandId) {
 				commandRegistry.registerCommandContribution(viewActionsScope, commandId, 1, "orion.menuBarViewGroup/eclipse.fileCommandExtensions"); //$NON-NLS-0$
 				commandRegistry.registerCommandContribution(contextMenuActionsScope, commandId, 1, "orion.commonNavContextMenuGroup/orion.relatedActions/orion.Extensions"); //$NON-NLS-0$
 			});
-			
+
 			// Retrieve and register project commands
 			return this.preferences.get("/common-nav").then(function(prefs) { //$NON-NLS-0$
-				var show = prefs["showNewProjectCommands"]; //$NON-NLS-0$
+				var show = prefs["showNewProjectCommands"];
 				if (show === undefined || show) {
 					commandRegistry.addCommandGroup(fileActionsScope, "orion.projectsNewGroup", 100, messages["Project"], "orion.menuBarFileGroup/orion.newContentGroup"); //$NON-NLS-1$ //$NON-NLS-0$
 					commandRegistry.addCommandGroup(contextMenuActionsScope, "orion.projectsNewGroup", 100, messages["Project"], "orion.commonNavContextMenuGroup/orion.newGroup/orion.New"); //$NON-NLS-1$ //$NON-NLS-0$
 					var position = 0;
-					ProjectCommands.getCreateProjectCommands(commandRegistry).forEach(function(command){
+					ProjectCommands.getCreateProjectCommands(commandRegistry).forEach(function(command) {
 						if (!util.isElectron) {
 							commandRegistry.registerCommandContribution(fileActionsScope, command.id, position, "orion.menuBarFileGroup/orion.newContentGroup/orion.projectsNewGroup"); //$NON-NLS-0$
 							commandRegistry.registerCommandContribution(contextMenuActionsScope, command.id, position, "orion.commonNavContextMenuGroup/orion.newGroup/orion.New/orion.projectsNewGroup"); //$NON-NLS-0$
@@ -406,6 +395,9 @@ define([
 				}
 			});
 		},
+		/**
+		 * @callback
+		 */
 		updateCommands: function(selections) {
 			var visible = this.isCommandsVisible();
 			this.createActionSections();
@@ -418,52 +410,52 @@ define([
 				this._populateContextMenu(this._sidebarContextMenuNode);
 			}
 		},
-		
+
 		getEditActionsScope: function() {
-			return this.editActionsScope;	
+			return this.editActionsScope;
 		},
-		
+
 		getTreeRoot: function() {
 			return this.treeRoot;
 		},
-		
+
 		_populateContextMenu: function(contextMenuNode) {
 			var selectionService = this.selection;
 			var selections = selectionService.getSelections();
 			var items = null;
-			
+
 			this.commandRegistry.destroy(contextMenuNode); // remove previous content
-			
+
 			if (!selections || (Array.isArray(selections) && !selections.length)) {
 				//no selections, use this.treeRoot to determine commands
 				items = this.getTreeRoot();
 			}
-			this.commandRegistry.renderCommands(this.contextMenuActionsScope, contextMenuNode, items, this, "menu");  //$NON-NLS-0$	
+			this.commandRegistry.renderCommands(this.contextMenuActionsScope, contextMenuNode, items, this, "menu"); //$NON-NLS-0$
 		},
-		
+
 		refreshSelection: function() {
 			//Do nothing
 		},
-			
+
 		_createContextMenu: function() {
 			//function called when the context menu is triggered to set the nav selection properly
 			var contextMenuTriggered = function(eventWrapper) {
 				var navHandler = this.getNavHandler();
 				var navDict = this.getNavDict();
-				var event = eventWrapper.event;
+				var evnt = eventWrapper.event;
 				var item = null;
-				
-				if (event.target) {
-					var node = event.target;
+
+				if (evnt.target) {
+					var node = evnt.target;
 					while (this._parentNode.contains(node)) {
-						if ("TR" === node.nodeName) {	//$NON-NLS-0$ //TODO this is brittle, see if a better way exists
+						if ("TR" === node.nodeName) { //TODO this is brittle, see if a better way exists
 							var rowId = node.id;
 							item = navDict.getValue(rowId);
 							break;
 						}
 						node = node.parentNode;
 					}
-					
+
 					if (item && !navHandler.isDisabled(item.rowDomNode)) {
 						// only modify the selection if the item that the context menu
 						// was triggered on isn't already part of the selection
@@ -475,7 +467,7 @@ define([
 					} else {
 						// context menu was triggered on sidebar itself,
 						// clear previous selections
-						var triggerX = event.offsetX === undefined ? event.layerX : event.offsetX;
+						var triggerX = evnt.offsetX === undefined ? evnt.layerX : evnt.offsetX;
 						if (triggerX > 0) { // X coordinate should be greater than 0 if mouse right button was used
 							this.selection.setSelections(null);
 							navHandler.refreshSelection(true, true);
@@ -484,14 +476,14 @@ define([
 					mMetrics.logEvent("contextMenu", "opened", "navigator"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 				}
 			}.bind(this);
-			
+
 			var contextMenu = new mContextMenu.ContextMenu({
 				dropdown: this._sidebarContextMenuNode,
 				triggerNode: this._parentNode
 			});
-			
-			contextMenu.addEventListener("triggered", contextMenuTriggered); //$NON-NLS-0$
-			
+
+			contextMenu.addEventListener("triggered", contextMenuTriggered);
+
 			this._contextMenu = contextMenu;
 		}
 	});
@@ -503,22 +495,22 @@ define([
 	objects.mixin(CommonNavRenderer.prototype, {
 		showFolderLinks: true,
 		oneColumn: true,
-		
+
 		_preventLinkBehavior: function(linkNode) {
 			linkNode.addEventListener("click", function(evt) {
-	            this.explorer.isDesktopSelectionMode().then(function(desktopMode){
-	            	if(_DEBUG) {
-	            		var byWho = evt.detail ===3 ? "simulation" : "user";
-		            	console.log("single click triggered by " + byWho);
-		            	console.log(evt);
-	            	}
-	            	if(desktopMode && (evt.shiftKey || evt.ctrlKey || evt.metaKey) && evt.detail !==3) {
-	            		if(_DEBUG) {
-	            			console.log("single click prevented");
-            			}
-	            		evt.preventDefault();
-	            	}
-	            });
+				this.explorer.isDesktopSelectionMode().then(function(desktopMode) {
+					if (_DEBUG) {
+						var byWho = evt.detail === 3 ? "simulation" : "user";
+						console.log("single click triggered by " + byWho);
+						console.log(evt);
+					}
+					if (desktopMode && (evt.shiftKey || evt.ctrlKey || evt.metaKey) && evt.detail !== 3) {
+						if (_DEBUG) {
+							console.log("single click prevented");
+						}
+						evt.preventDefault();
+					}
+				});
 			}.bind(this));
 			linkNode.addEventListener("dblclick", function(evt) {
 				this.explorer.handleLinkDoubleClick(linkNode, evt);
@@ -526,8 +518,10 @@ define([
 		},
 		createFolderNode: function(folder) {
 			var folderNode = NavigatorRenderer.prototype.createFolderNode.call(this, folder);
-			if (this.showFolderLinks && folderNode.tagName === "A") { //$NON-NLS-0$
-				folderNode.href = uriTemplate.expand({resource: folder.Location});
+			if (this.showFolderLinks && folderNode.tagName === "A") {
+				folderNode.href = uriTemplate.expand({
+					resource: folder.Location
+				});
 				folderNode.classList.add("commonNavFolder"); //$NON-NLS-0$
 			} else {
 				folderNode.classList.add("nav_fakelink"); //$NON-NLS-0$
@@ -535,6 +529,9 @@ define([
 			this._preventLinkBehavior(folderNode);
 			return folderNode;
 		},
+		/**
+		 * @callback
+		 */
 		updateFileNode: function(file, fileNode, isImage) {
 			this._preventLinkBehavior(fileNode);
 		},
@@ -544,26 +541,25 @@ define([
 		 */
 		rowCallback: function(rowElement, model) {
 			NavigatorRenderer.prototype.rowCallback.call(this, rowElement, model);
-			
+
 			// Search for the model in the Cut buffer and disable it if it is found
 			var cutBuffer = FileCommands.getCutBuffer();
 			if (cutBuffer) {
 				var matchFound = cutBuffer.some(function(cutModel) {
 					return FileCommands.isEqualToOrChildOf(model, cutModel);
 				});
-				
+
 				if (matchFound) {
 					var navHandler = this.explorer.getNavHandler();
 					navHandler.disableItem(model);
 				}
 			}
 		},
-		emptyCallback: function() {
-		}
+		emptyCallback: function() {}
 	});
-	
+
 	return {
 		CommonNavExplorer: CommonNavExplorer,
 		CommonNavRenderer: CommonNavRenderer
 	};
-});
+});
\ No newline at end of file
