@@ -7,6 +7,7 @@
  * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
  * 
  * Contributors: Anton McConville - IBM Corporation - initial API and implementation
+ *               Casey Flynn - Google Inc - Addition of Platform Styles.
  ******************************************************************************/
 /*eslint-env browser, amd*/
 
@@ -28,12 +29,19 @@ define([
 	'orion/status',
 	'orion/widgets/themes/ThemePreferences',
 	'orion/widgets/themes/editor/ThemeData',
+	'orion/widgets/themes/container/ThemeData',
 	'orion/widgets/themes/ThemeImporter',
 	'orion/widgets/settings/SplitSelectionLayout',
 	'orion/widgets/plugin/PluginList',
 	'orion/widgets/settings/GitSettings',
 	'orion/widgets/settings/EditorSettings',
+	'orion/widgets/themes/EditorWidget',
+	'orion/widgets/themes/ContainerWidget',
 	'orion/widgets/settings/ThemeSettings',
+	'orion/widgets/themes/container/ContainerSetup',
+	'orion/widgets/themes/editor/editorSetup',
+	'orion/widgets/themes/container/ContainerScopeList',
+	'orion/widgets/themes/editor/EditorScopeList',
 	'orion/widgets/settings/UserSettings',
 	'orion/widgets/settings/GlobalizationSettings',
 	'orion/widgets/settings/GeneralSettings',
@@ -42,8 +50,9 @@ define([
 	'orion/metrics',
 	'orion/util',
 ], function(messages, mCommands, mGlobalCommands, PageUtil, lib, i18nUtil, objects, mOperationsClient, URITemplate, 
-		ThemeBuilder, SettingsList, mStatus, mThemePreferences, editorThemeData, editorThemeImporter, SplitSelectionLayout, PluginList, 
-		GitSettings, EditorSettings, ThemeSettings, UserSettings, GlobalizationSettings, GeneralSettings, mEditorPreferences, mGeneralPreferences, mMetrics, util) {
+		ThemeBuilder, SettingsList, mStatus, mThemePreferences, editorThemeData, containerThemeData, editorThemeImporter, SplitSelectionLayout, PluginList, 
+		GitSettings, EditorSettings, EditorWidget, ContainerWidget, ThemeSettings, ContainerSetup, editorSetup, ContainerScopeList, EditorScopeList, UserSettings, GlobalizationSettings, GeneralSettings, 
+		mEditorPreferences, mGeneralPreferences, mMetrics, util) {
 
 	
 	/**
@@ -119,6 +128,15 @@ define([
 					});
 				}
 				
+				if (categories.showContainerThemeSettings === undefined || categories.showContainerThemeSettings) {
+					_self.settingsCategories.push({
+						id: "conatinerThemeSettings", //$NON-NLS-0$
+						//TODO(caseyflynn): Add to messages.ContainerTheme
+						textContent: "Platform Styles",
+						show: _self.showContainerThemeSettings
+					});
+				}
+				
 				if (categories.showEditorSettings === undefined || categories.showEditorSettings) {
 					_self.settingsCategories.push({
 						id: "editorSettings", //$NON-NLS-0$
@@ -308,8 +326,29 @@ define([
 			var editorTheme = new editorThemeData.ThemeData();
 			var themeImporter = new editorThemeImporter.ThemeImporter();
 			var themePreferences = new mThemePreferences.ThemePreferences(this.preferences, editorTheme);
-			var editorThemeWidget = new ThemeBuilder({ commandService: this.commandService, preferences: themePreferences, themeData: editorTheme, toolbarId: 'editorThemeSettingsToolActionsArea', serviceRegistry: this.registry}); //$NON-NLS-0$
+			var scopeList = EditorScopeList;
+			var previewWidget = new EditorWidget({scopeList: scopeList});
+			var setup = editorSetup;
 
+			var themeWidget = new ThemeBuilder({
+				commandService: this.commandService, 
+				preferences: themePreferences, 
+				themeData: editorTheme, 
+				toolbarId: 'editorThemeSettingsToolActionsArea', 
+				scopeList: scopeList,
+				previewWidget: previewWidget,
+				setup: setup,
+				serviceRegistry: this.registry});
+
+			var exportCommand = new mCommands.Command({
+				name: messages.Export,
+				tooltip: messages['Export a theme'],
+				id: "orion.exportTheme",
+				callback: themeWidget.exportTheme
+			});
+			this.commandService.addCommand(exportCommand);
+			this.commandService.registerCommandContribution('themeCommands', "orion.exportTheme", 5); //$NON-NLS-1$ //$NON-NLS-0$			
+			
 			var command = new mCommands.Command({
 				name:messages.Import,
 				tip:messages['Import a theme'],
@@ -318,13 +357,16 @@ define([
 			});
 			this.commandService.addCommand(command);
 			this.commandService.registerCommandContribution('themeCommands', "orion.importTheme", 4); //$NON-NLS-1$ //$NON-NLS-2$
+
 			var editorPreferences = new mEditorPreferences.EditorPreferences (this.preferences);
 
 			this.themeSettings = new ThemeSettings({
+				id: "editorThemeSettings", //$NON-NLS-0$
+				title: messages.EditorThemes,
 				registry: this.registry,
 				preferences: editorPreferences,
 				themePreferences: themePreferences,
-				editorThemeWidget: editorThemeWidget,
+				themeWidget: themeWidget,
 				statusService: this.preferencesStatusService,
 				dialogService: this.preferenceDialogService,
 				commandService: this.commandService,
@@ -334,6 +376,54 @@ define([
 			this.themeSettings.show();
 		},
 		
+		showContainerThemeSettings: function(id){
+			this.selectCategory(id);
+			
+			lib.empty(this.table);
+			
+			this.updateToolbar(id);
+			
+			var themeSettingsNode = document.createElement('div');
+			this.table.appendChild(themeSettingsNode);
+			
+			var containerTheme = new containerThemeData.ThemeData();
+			var themePreferences = new mThemePreferences.ThemePreferences(this.preferences, containerTheme);
+			var previewWidget = new ContainerWidget();
+			var scopeList = ContainerScopeList;
+			var setup = ContainerSetup;
+			
+			var themeWidget = new ThemeBuilder({
+				commandService: this.commandService, 
+				preferences: themePreferences, 
+				themeData: containerTheme, 
+				toolbarId: 'containerThemeSettingsToolActionsArea',
+				scopeList: scopeList,
+				previewWidget: previewWidget,
+				setup: setup,
+				serviceRegistry: this.registry});
+
+			// Currently there is no support for exporting / importing container themes.
+			this.commandService.unregisterCommandContribution('themeCommands', "orion.importTheme");
+			this.commandService.unregisterCommandContribution('themeCommands', "orion.exportTheme");
+			
+			var editorPreferences = new mEditorPreferences.EditorPreferences (this.preferences);
+			this.containerThemeSettings = new ThemeSettings({
+				id: "containerThemeSettings",
+				title: messages.ContainerThemes,
+				registry: this.registry,
+				preferences: editorPreferences,
+				themePreferences: themePreferences,
+				themeWidget: themeWidget,
+				statusService: this.preferencesStatusService,
+				dialogService: this.preferenceDialogService,
+				commandService: this.commandService,
+				userClient: this.userClient
+			}, themeSettingsNode);
+			
+			this.containerThemeSettings.show();
+			
+		},
+		
 		showGlobalizationSettings: function(id){
 
 			this.selectCategory(id);
@@ -512,9 +602,6 @@ define([
 
 		addCategory: function(category) {
 			category['class'] = (category['class'] || '') + ' navbar-item'; //$NON-NLS-1$ //$NON-NLS-0$
-			category.role = "tab"; //$NON-NLS-1$
-			category.tabindex = -1;
-			category["aria-selected"] = "false"; //$NON-NLS-1$
 			category.onclick = category.show;
 			superPrototype.addCategory.apply(this, arguments);
 		},
@@ -540,4 +627,4 @@ define([
 		}
 	});
 	return SettingsContainer;
-});
+});
\ No newline at end of file
